@@ -11,7 +11,7 @@ from octue.utils.folders import get_file_name_from_strand
 from twined import ALL_STRANDS, Twine
 
 
-module_logger = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 HASH_FUNCTIONS = {
@@ -99,7 +99,7 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
             raise InvalidMonitorMessage(e)
 
         if self._handle_monitor_message is None:
-            module_logger.warning("Attempted to send a monitor message but no handler is specified.")
+            logger.warning("Attempted to send a monitor message but no handler is specified.")
             return
 
         self._handle_monitor_message(data)
@@ -118,7 +118,7 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
         serialised_strands = {}
 
         for output_strand in OUTPUT_STRANDS:
-            self.logger.debug("Serialising %r", output_strand)
+            logger.debug("Serialising %r", output_strand)
 
             attribute = getattr(self, output_strand)
             if attribute is not None:
@@ -126,7 +126,7 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
 
             serialised_strands[output_strand] = attribute
 
-        self.logger.debug("Validating serialised output json against twine")
+        logger.debug("Validating serialised output json against twine")
         self.twine.validate(**serialised_strands)
 
         # Optionally write the serialised strands to disk.
@@ -137,13 +137,13 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
                     filename = get_file_name_from_strand(output_strand, output_dir)
                     with open(filename, "w") as fp:
                         fp.write(serialised_strands[output_strand])
-                    self.logger.debug("Wrote %r to file %r", output_strand, filename)
+                    logger.debug("Wrote %r to file %r", output_strand, filename)
 
         # Optionally write the manifest to Google Cloud storage.
         if upload_to_cloud:
             if hasattr(self, "output_manifest"):
                 self.output_manifest.to_cloud(project_name, bucket_name, output_dir)
-                self.logger.debug(
+                logger.debug(
                     "Wrote %r to cloud storage at project %r in bucket %r.",
                     self.output_manifest,
                     project_name,
