@@ -55,6 +55,26 @@ class Dataset(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiabl
     def __len__(self):
         return len(self.files)
 
+    @classmethod
+    def from_local_directory(cls, path_to_directory, recursive=False):
+        """Instantiate a Dataset from the files in the given local directory.
+
+        :param str path_to_directory: path to a local directory
+        :param bool recursive: if `True`, include all files in the directory's subdirectories recursively
+        :return Dataset:
+        """
+        datafiles = FilterSet()
+
+        for level, (directory_path, _, filenames) in enumerate(os.walk(path_to_directory)):
+            for filename in filenames:
+
+                if not recursive and level > 0:
+                    break
+
+                datafiles.add(Datafile(path=os.path.join(directory_path, filename)))
+
+        return Dataset(path=path_to_directory, files=datafiles)
+
     @classmethod
     def from_cloud(
         cls,
@@ -125,12 +145,31 @@ class Dataset(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiabl
         if not cloud_path:
             cloud_path = storage.path.generate_gs_path(bucket_name, output_directory, self.name)
 
+        files_and_paths = []
+
         for datafile in self.files:
-            datafile.to_cloud(
-                project_name,
-                cloud_path=storage.path.join(cloud_path, datafile.name),
+            datafile_path_relative_to_dataset = datafile.path.split(self.path)[-1].strip(os.path.sep).strip("/")
+            files_and_paths.append(
+                (
+                    datafile,
+                    storage.path.join(cloud_path, *datafile_path_relative_to_dataset.split(os.path.sep)),
+                )
             )
 
+        def upload(iterable_element):
+            """Upload a datafile to the given cloud path.
+
+            :param tuple(octue.resources.datafile.Datafile, str) iterable_element:
+            :return None:
+            """
+            datafile = iterable_element[0]
+            cloud_path = iterable_element[1]
+            datafile.to_cloud(project_name, cloud_path=cloud_path)
+
+        # Use multiple threads to significantly speed up file uploads by reducing latency.
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            executor.map(upload, files_and_paths)
+
         self._upload_metadata_file(project_name, cloud_path)
         return cloud_path
 
@@ -249,7 +288,7 @@ class Dataset(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiabl
             return datafile.download(local_path=local_path)
 
         # Use multiple threads to significantly speed up files downloads by reducing latency.
-        with concurrent.futures.ThreadPoolExecutor(max_workers=10) as executor:
+        with concurrent.futures.ThreadPoolExecutor() as executor:
             executor.map(download, files_and_paths)
 
     def _upload_metadata_file(self, project_name, cloud_path):
